@@ -81,13 +81,17 @@ def from_uuid(suffix: uuid6.UUID, prefix: Optional[str] = None) -> TypeID:
 
 def get_prefix_and_suffix(string: str) -> tuple:
     parts = string.rsplit("_", 1)
+
+    # When there's no underscore in the string.
     if len(parts) == 1:
-        prefix = None
-        suffix = parts[0]
-    elif len(parts) == 2 and parts[0] == "":
+        if parts[0].strip() == "":
+            raise InvalidTypeIDStringException(f"Invalid TypeID: {string}")
+        return None, parts[0]
+
+    # When there is an underscore, unpack prefix and suffix.
+    prefix, suffix = parts
+    if prefix.strip() == "" or suffix.strip() == "":
         raise InvalidTypeIDStringException(f"Invalid TypeID: {string}")
-    else:
-        prefix, suffix = parts
 
     return prefix, suffix
 
